# Utilitys
## General Python Utilities

A collection of PyQt gui builders and other functions I've found helpful as I develop python mockups.

## Installation
```bash
git clone https://gitlab.com/ntjess/utilitys
pip install -e ./utilitys
```

## Usage
Usage will vary depending on the requested capabilities. Check out the `examples` folder for some usages